@@ -534,7 +534,7 @@ inform_node_status(LifeCheckNode * node, char *message)
 	if (json_data == NULL)
 		return false;
 
-	for (x = 0; x < MAX_SEC_WAIT_FOR_CLUSTER_TRANSATION; x++)
+	for (x = 0; x < MAX_SEC_WAIT_FOR_CLUSTER_TRANSACTION; x++)
 	{
 		res = issue_command_to_watchdog(WD_NODE_STATUS_CHANGE_COMMAND, 0, json_data, strlen(json_data), false);
 		if (res)
@@ -690,7 +690,7 @@ is_wd_lifecheck_ready(void)
 		else
 		{
 			ereport(ERROR,
-					(errmsg("checking if watchdog is ready, unkown watchdog mode \"%d\"",
+					(errmsg("checking if watchdog is ready, unknown watchdog mode \"%d\"",
 							pool_config->wd_lifecheck_method)));
 		}
 	}
@@ -1017,11 +1017,11 @@ wd_ping_pgpool(LifeCheckNode * node, char* password)
 	conn = create_conn(node->hostName, node->pgpoolPort, password);
 	if (conn == NULL)
 	{
-		if(check_password_type_is_not_md5(pool_config->wd_lifecheck_user, pool_config->wd_lifecheck_password) == -1)
+		if(chceck_password_type_is_not_md5(pool_config->wd_lifecheck_user, pool_config->wd_lifecheck_password) == -1)
 		{
 			ereport(ERROR,
 					(errmsg("the password of wd_lifecheck_user %s is invalid format",
-						pool_config->wd_lifecheck_user),
+						pool_config->recovery_user),
 					errdetail("wd_lifecheck_password is not allowed to be md5 hashed format")));
 		}
 		return WD_NG;
@@ -1029,7 +1029,7 @@ wd_ping_pgpool(LifeCheckNode * node, char* password)
 	return ping_pgpool(conn);
 }
 
-/* inner function for issueing lifecheck query */
+/* inner function for issuing lifecheck query */
 static int
 ping_pgpool(PGconn *conn)
 {
